Implementation Report
=====================

Below is the latest implementation report, generated by the ``report.py`` script and included verbatim from ``report.txt``:

.. literalinclude:: ../report.txt
